@@ -11,6 +11,7 @@
 #' @param cache logical; TRUE if temporary data cubes should be cached to support fast reprocessing of the same cubes
 #' @param ncdf_write_bounds logical; write dimension bounds as additional variables in netCDF files
 #' @param use_overview_images logical; if FALSE, all images are read on original resolution and existing overviews will be ignored
+#' @param show_progress logical; if TRUE, a progress bar will be shown for actual computations
 #' @details 
 #' Data cubes can be processed in parallel where one thread processes one chunk at a time. Setting more threads
 #' than the number of chunks of a cube thus has no effect and will not further reduce computation times.
@@ -24,8 +25,10 @@
 #' @examples 
 #' gdalcubes_options(threads=4) # set the number of threads
 #' gdalcubes_options() # print current options
+#' gdalcubes_options(threads=1) # reset
 #' @export
-gdalcubes_options <- function(..., threads, ncdf_compression_level, debug, cache, ncdf_write_bounds, use_overview_images) {
+gdalcubes_options <- function(..., threads, ncdf_compression_level, debug, cache, ncdf_write_bounds, 
+                              use_overview_images, show_progress) {
   if (!missing(threads)) {
     stopifnot(threads >= 1)
     stopifnot(threads%%1==0)
@@ -55,6 +58,11 @@ gdalcubes_options <- function(..., threads, ncdf_compression_level, debug, cache
     .pkgenv$use_overview_images = use_overview_images
     libgdalcubes_set_use_overviews(use_overview_images)
   }
+  if (!missing(show_progress)) {
+    stopifnot(is.logical(show_progress))
+    .pkgenv$show_progress = show_progress
+    libgdalcubes_set_progress(show_progress)
+  }
 
   
   # if (!missing(swarm)) {
@@ -71,30 +79,12 @@ gdalcubes_options <- function(..., threads, ncdf_compression_level, debug, cache
       debug = .pkgenv$debug,
       cache = .pkgenv$use_cube_cache,
       ncdf_write_bounds = .pkgenv$ncdf_write_bounds,
-      use_overview_images = .pkgenv$use_overview_images
+      use_overview_images = .pkgenv$use_overview_images,
+      show_progress = .pkgenv$show_progress
     ))
   }
 }
 
-
-
-#' Set the number of threads for parallel data cube processing
-#'
-#' Data cubes can be processed in parallel where one thread processes one chunk at a time. Setting more threads
-#' than the number of chunks of a cube thus has no effect and will not further reduce computation times.
-#' @param n number of threads
-#' @examples 
-#' gdalcubes_set_threads(1)
-#' @note THIS FUNCTION IS DEPRECATED AND IS GOING TO BE REPLACED BY \code{\link{gdalcubes_options}}.
-#' @export
-gdalcubes_set_threads <- function(n=1) {
-  stopifnot(n >= 1)
-  stopifnot(n%%1==0)
-  libgdalcubes_set_threads(n)
-  .pkgenv$threads = n
-  invisible()
-}
-
 #' Query gdalcubes version information
 #'
 #' @return List with gdalcubes library version information
@@ -105,34 +95,6 @@ gdalcubes_version <- function() {
   return(libgdalcubes_version())
 }
 
-#' Enable or disable debug output from the gdalcubes C++ library
-#' @param debug logical, TRUE if you want debug messages
-#' @examples 
-#' gdalcubes_debug_output(TRUE)
-#' gdalcubes_debug_output(FALSE)
-#' @note THIS FUNCTION IS DEPRECATED AND IS GOING TO BE REPLACED BY \code{\link{gdalcubes_options}}.
-#' @export
-gdalcubes_debug_output <- function(debug=TRUE) {
-   libgdalcubes_debug_output(debug)
-  .pkgenv$debug = debug
-  invisible()
-}
-
-
-#' Set compression level for netCDF files produced by gdalcubes
-#' @param level integer; compression level, 0 = no compression, 1=fast compression, 9=small compression
-#' @examples 
-#' gdalcubes_set_ncdf_compression(9) # maximum compression
-#' gdalcubes_set_ncdf_compression(0) # no compression
-#' @note THIS FUNCTION IS DEPRECATED AND IS GOING TO BE REPLACED BY \code{\link{gdalcubes_options}}.
-#' @export
-gdalcubes_set_ncdf_compression <- function(level=2) {
-  stopifnot(level %% 1 == 0)
-  stopifnot(level >= 0 && level <= 9)
-  .pkgenv$compression_level = level
-  invisible()
-}
-
 #' Get available GDAL drivers
 #' @examples 
 #' gdalcubes_gdalformats()
@@ -159,20 +121,4 @@ gdalcubes_gdalversion <- function() {
 }
 
 
-#' Enable or disable caching of cubes.
-#' 
-#' @details
-#' Caching has no effect on disk or memory consumption, 
-#' it simply tries to reuse existing temporary files where possible.
-#' For example, changing only parameters to \code{plot} will not require
-#' rerunning the full data cube operation chain.
-#' 
-#' @param enable logical, TRUE if you want to use the data cube cache
-#' @examples 
-#' gdalcubes_use_cache(FALSE)
-#' @note THIS FUNCTION IS DEPRECATED AND IS GOING TO BE REPLACED BY \code{\link{gdalcubes_options}}.
-#' @export
-gdalcubes_use_cache <- function(enable=TRUE) {
-  .pkgenv$use_cube_cache = enable
-}
 
