@@ -237,7 +237,9 @@ datetime datetime::from_string(std::string s) {
     std::istringstream is(s);
 
     // TODO: Regex does not support ISO weeks / day of year yet
-    std::regex regex1("([0-9]{4})(?:-?([0-9]{2})(?:-?([0-9]{2})(?:[T\\s]?([0-9]{2})(?::?([0-9]{2})(?::?([0-9]{2}))?)?)?)?)?(?:Z|(?:(?:\\+|-)[0-9]{2}(?::?[0-9]{2})?))?");
+    //std::regex regex1("([0-9]{4})(?:-?([0-9]{2})(?:-?([0-9]{2})(?:[T\\s]?([0-9]{2})(?::?([0-9]{2})(?::?([0-9]{2}))?)?)?)?)?(?:Z|(?:(?:\\+|-)[0-9]{2}(?::?[0-9]{2})?))?");
+    std::regex regex1("([0-9]{4})(?:-?([0-9]{2})(?:-?([0-9]{2})(?:[T\\s]?([0-9]{2})(?::?([0-9]{2})(?::?([0-9]{2})(?:[.,][0-9]+)?)?)?)?)?)?(?:Z|(?:(?:\\+|-)[0-9]{2}(?::?[0-9]{2})?))?");
+
     datetime out;
 
     std::cmatch res;
